==> haskell-deriving-aeson-0.2.8-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deriving-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deriving-aeson
version:              0.2.8
visibility:           public
id:                   deriving-aeson-0.2.8-1rd2vwQinE54xtpHbxGmVW
key:                  deriving-aeson-0.2.8-1rd2vwQinE54xtpHbxGmVW
license:              BSD-3-Clause
copyright:            Copyright (c) 2020 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Type driven generic aeson instance customisation
description:
    This package provides a newtype wrapper with
    FromJSON/ToJSON instances customisable via a phantom type parameter.
    The instances can be rendered to the original type using DerivingVia.

category:             JSON, Generics
abi:                  97b6a976e414ff8fb3721d5cd6832412
exposed:              True
exposed-modules:      Deriving.Aeson Deriving.Aeson.Stock
import-dirs:          /usr/lib/ghc-9.0.2/site-local/deriving-aeson-0.2.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/deriving-aeson-0.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/deriving-aeson-0.2.8
hs-libraries:         HSderiving-aeson-0.2.8-1rd2vwQinE54xtpHbxGmVW
depends:              aeson-1.5.6.0-BBhdcnlV5J5JNtwcCn5l4o base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-deriving-aeson/html/deriving-aeson.haddock

haddock-html:         /usr/share/doc/haskell-deriving-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deriving-aeson-0.2.8-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deriving-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deriving-aeson
version:              0.2.8
visibility:           public
id:                   deriving-aeson-0.2.8-obsMaHGgsw84mOWWpK0Eo
key:                  deriving-aeson-0.2.8-obsMaHGgsw84mOWWpK0Eo
license:              BSD-3-Clause
copyright:            Copyright (c) 2020 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Type driven generic aeson instance customisation
description:
    This package provides a newtype wrapper with
    FromJSON/ToJSON instances customisable via a phantom type parameter.
    The instances can be rendered to the original type using DerivingVia.

category:             JSON, Generics
abi:                  77861400542e49e09c6a9f951bd8a5fe
exposed:              True
exposed-modules:      Deriving.Aeson Deriving.Aeson.Stock
import-dirs:          /usr/lib/ghc-9.0.2/site-local/deriving-aeson-0.2.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/deriving-aeson-0.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/deriving-aeson-0.2.8
hs-libraries:         HSderiving-aeson-0.2.8-obsMaHGgsw84mOWWpK0Eo
depends:              aeson-1.5.6.0-9b7PYeIt4IK50V585g1cEG base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-deriving-aeson/html/deriving-aeson.haddock

haddock-html:         /usr/share/doc/haskell-deriving-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
